package org.jeecg;

import cn.com.ctop.common.module.entity.BindAccountLogin;
import cn.com.ctop.common.module.entity.CtopOauthToken;
import cn.com.ctop.common.module.entity.UserAllocation;
import cn.com.ctop.common.module.message.handle.impl.EmailSendMsgHandle;
import cn.com.ctop.common.module.service.*;
import cn.com.ctop.common.module.utils.CtopAdConstant;
import cn.com.ctop.kuaishou.modules.batch.service.IKuaiShouDailyReportTaskService;
import cn.com.ctop.kuaishou.modules.batch.service.IKuaiShouHistoryReportTaskService;
import cn.com.ctop.kuaishou.modules.batch.service.IKuaishouInterfaceService;
import cn.com.ctop.kuaishou.modules.graphql.service.IKuaishouWebInterfaceService;
import cn.com.ctop.kuaishou.modules.report.entity.KuaishouAgentAccount;
import cn.com.ctop.kuaishou.modules.report.mapper.KuaishouAgentAccountMapper;
import cn.com.ctop.kuaishou.modules.report.service.IKuaishouReportDailyAgentService;
import cn.com.ctop.toutiao.modules.material.service.IByteDanceAdvertiserDataService;
import cn.com.ctop.toutiao.modules.report.service.IBytedanceFundDailyService;
import cn.com.ctop.toutiao.modules.report.service.IBytedanceReportService;
import cn.com.ctop.toutiao.modules.report.service.IReportService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.xxl.job.core.log.XxlJobLogger;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.util.DateUtils;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.junit4.SpringRunner;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

import static org.jeecg.common.util.DateUtils.getAnotherDay;

@RunWith(SpringRunner.class)
@SpringBootTest(webEnvironment = SpringBootTest.WebEnvironment.RANDOM_PORT)
@ActiveProfiles("wps")
@Slf4j
public class SampleTest {
    @Autowired
    private ICtopOauthTokenService oauthTokenService;
    @Autowired
    private IReportService reportService;
    @Autowired
    private IByteDanceAdvertiserDataService advertiserDataService;
    @Autowired
    private IKuaiShouHistoryReportTaskService kuaiShouHistoryReportTaskService;

    @Autowired
    private ICtopOauthTokenService tokenService;

    @Test
    public void loadBytedanceCreativeData() {
        QueryWrapper<CtopOauthToken> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("media_id", 2);
        List<CtopOauthToken> list = oauthTokenService.list(queryWrapper);
        for (CtopOauthToken token : list) {
            kuaiShouHistoryReportTaskService.createTask(token.getAccountId(), token.getAccessToken(), "2020-09-20", "2020-09-20", "daily");
        }
    }

    @Autowired
    private IBindAccountLoginService bindAccountLoginService;
    @Autowired
    private IKuaishouWebInterfaceService kuaishouWebInterfaceService;

    @Test
    public void loadKuaishouCookie() {
        List<BindAccountLogin> list = bindAccountLoginService.getListByParams(CtopAdConstant.PLATFORM_TYPE_KUAISHOU_PY, 1);
        if (list != null && !list.isEmpty()) {
            int i = 0;
            for (BindAccountLogin login : list) {
                if (null == login.getCookie() || "".equals(login.getCookie().trim())) {
                    if (i > 5) {
                        break;
                    }
                    kuaishouWebInterfaceService.getkuaishouWebLoginCookie(login);
                    i++;
                }
            }
        }
    }

    static ExecutorService executorService = null;
    //线程计数器/bytedance/bytedanceMaterialReport
    static CountDownLatch countDownLatch = null;

    @Test
    public void deleteKuaishouComment() {
        Long start = System.currentTimeMillis();
        List<BindAccountLogin> loginList = bindAccountLoginService.getListByParams(CtopAdConstant.PLATFORM_TYPE_KUAISHOU_PY, 1);
        if (loginList != null && !loginList.isEmpty()) {
            executorService = Executors.newFixedThreadPool(5);
            countDownLatch = new CountDownLatch(loginList.size());
            loginList.forEach(login -> executorService.submit(() -> {
                try {
                    kuaishouWebInterfaceService.deleteAllComment(new HashMap<>(), login);
                } catch (Exception e) {
                    log.error(e.getMessage(), e);
                } finally {
                    countDownLatch.countDown();
                }
            }));
            try {
                countDownLatch.await();
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            Long end = System.currentTimeMillis();
            log.info("快手删评论所用时长：{}毫秒", end - start);
        }
    }

    @Autowired
    private IUserAllocationService allocationService;

    @Test
    public void testLoadBytedanceData() {
        List<UserAllocation>allocations = allocationService.getByParams(273L,null,0);
        if(null!=allocations&&!allocations.isEmpty()){
            for(UserAllocation allocation:allocations){
                CtopOauthToken token = tokenService.getTokenByAccountId(allocation.getAccountId());
                String startDate = "2020-11-05";
                String endDate = "2020-11-09";
                reportService.getAdvertiserPlanReport(token, DateUtils.parseDate(startDate,"yyyy-MM-dd"), DateUtils.parseDate(endDate,"yyyy-MM-dd"), CtopAdConstant.BYTEDANCE_REPORT_TYPE_DAILY);
            }
        }
        System.out.println("任务结束");
    }

    @Test
    public void loadBytedancePlanData(){
        CtopOauthToken token = tokenService.getTokenByAccountId(100198696723L);
//        advertiserDataService.getAdvertiserPlan(token, "", null, null);
        Date getDate = DateUtils.addDay(new Date(), 0);
        reportService.getAdvertiserReport(token, getDate, getDate, CtopAdConstant.BYTEDANCE_REPORT_TYPE_HOURLY);
    }

    @Autowired
    private IBytedanceFundDailyService bytedanceFundDailyService;
    @Test
    public void loadFoudData() {
        List<CtopOauthToken> tokens = tokenService.selectToutiaoToken();
        for (CtopOauthToken token : tokens) {
            System.out.println(token.getAccountId()+"############################");
            for(int i=20;i<130;i++){
                Date date = DateUtils.addDay(new Date(),-i);
                bytedanceFundDailyService.loadFundDataByPage(token, DateUtils.formatDate(date), DateUtils.formatDate(date),1);
                System.out.println(i+"############################");
            }
        }
    }

    @Autowired
    private IKuaiShouHistoryReportTaskService reportTaskService;

    /**
     * 测试获取快手图片消耗数据任务
     */
    @Test
    public void loadKuaishouImageTask(){
        List<CtopOauthToken> tokens = tokenService.selectKuaiShouToken();
        for(int i=1;i<130;i++) {
            Date getDate = DateUtils.addDay(new Date(), -i);
            String getDateStr = DateUtils.formatDate(getDate);
            tokens.forEach(token -> reportTaskService.createTask(token.getAccountId(), token.getAccessToken(), getDateStr, getDateStr, CtopAdConstant.KUAISHOU_LOAD_JOB_TYPE_DAILY));
        }
    }

    @Autowired
    private IKuaiShouDailyReportTaskService dailyReportTaskService;
    /**
     * 测试获取快手图片消耗数据入库
     */
    @Test
    public void loadKuaishouImageTaskFile(){
        String nowDate = DateUtils.getDate("yyyy-MM-dd");
        List<CtopOauthToken> tokens = tokenService.selectKuaiShouToken();
        for(int i=1;i<15;i++){
            String statDate = getAnotherDay("yyyy-MM-dd", nowDate, -i);
            tokens.forEach(token -> dailyReportTaskService.getTaskList(token.getAccountId(), token.getAccessToken(), statDate));
        }
        //  查询快手token
    }

    @Test
    public void testLoadBytedanceImageData(){
        List<CtopOauthToken>tokens = tokenService.selectToutiaoToken();
        countDownLatch = new CountDownLatch(tokens.size());
        executorService = Executors.newFixedThreadPool(8);
        tokens.forEach(token->executorService.submit(()->{
            try {
                advertiserDataService.getMaterialList(token);
            }catch (Exception e){
            }finally {
                countDownLatch.countDown();
            }
        }));
        try {
            countDownLatch.await();
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        System.out.println("素材数据获取完成");

    }
    @Autowired
    private KuaishouAgentAccountMapper kuaishouAgentAccountMapper;
    @Autowired
    private IKuaishouReportDailyAgentService kuaishouReportDailyAgentService;
    @Test
    public void loadKuaishouAgentData() throws JsonProcessingException {
//        kuaishouReportDailyAgentService.loginAgent();
//        for (int i = 0; i < 20; i++) {
//            String currentDate = DateUtils.formatDate(DateUtils.addDay(new Date(), -i));
//            kuaishouReportDailyAgentService.getReport(currentDate, DateUtils.getNowDate("yyyy-MM-dd"));
//        }
//
//        try {
//            for (int i = 1; i < 30; i++) {
//                kuaishouReportDailyAgentService.getAccount(i);
//            }
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
        String result = "{\"result\":1,\"pageInfo\":{\"currentPage\":1,\"pageSize\":100,\"totalCount\":4357},\"reviewStatusCount\":{\"totalAccount\":4357,\"readToSummit\":14,\"inReview\":1,\"reviewSuccess\":3613,\"reviewFailed\":729},\"adDspAccountList\":[{\"userId\":2059566591,\"accountId\":8172118,\"accountName\":\"Cake\",\"createTime\":1604555890982,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"家园保卫战\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"天津酷划博达网络技术有限公司\",\"reviewStatus\":1,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1285337029,\"accountId\":8171255,\"accountName\":\"张大温柔.Chinese826\",\"createTime\":1604547032007,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"幸福农场\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"天津酷划博达网络技术有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2131468369,\"accountId\":8167058,\"accountName\":\"User_1604480565236\",\"createTime\":1604483311995,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"易车\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"天津伯优信息技术有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2131468369,\"accountId\":8167020,\"accountName\":\"User_1604480565236\",\"createTime\":1604483152676,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"易车\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"天津伯优信息技术有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2131468369,\"accountId\":8167010,\"accountName\":\"User_1604480565236\",\"createTime\":1604483102368,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"易车\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"天津伯优信息技术有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2131468369,\"accountId\":8167004,\"accountName\":\"User_1604480565236\",\"createTime\":1604483060825,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"易车\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"天津伯优信息技术有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2131468369,\"accountId\":8166978,\"accountName\":\"User_1604480565236\",\"createTime\":1604482973343,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"易车\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"天津伯优信息技术有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1343859197,\"accountId\":8166573,\"accountName\":\"我滴铁汁\",\"createTime\":1604480930275,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"维他奶京东自营旗舰店\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"电商商家\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"维他奶（上海）有限公司广州分公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2131441858,\"accountId\":8166349,\"accountName\":\"附近交友-未成年慎入\",\"createTime\":1604479797879,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱聊\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"深圳市金运网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2131441858,\"accountId\":8166287,\"accountName\":\"附近交友-未成年慎入\",\"createTime\":1604479435858,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱聊\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"深圳市金运网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2131441858,\"accountId\":8166281,\"accountName\":\"附近交友-未成年慎入\",\"createTime\":1604479386919,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱聊\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"深圳市金运网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2131441858,\"accountId\":8166252,\"accountName\":\"附近交友-未成年慎入\",\"createTime\":1604479192190,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱聊\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"深圳市金运网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2131441858,\"accountId\":8166218,\"accountName\":\"附近交友-未成年慎入\",\"createTime\":1604478995743,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱聊\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"深圳市金运网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1241072977,\"accountId\":8165639,\"accountName\":\"User_1549356012591\",\"createTime\":1604475811127,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"汽车之家\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京车之家信息技术有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2130800354,\"accountId\":8164532,\"accountName\":\"User_1604402150137\",\"createTime\":1604470064412,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2130800354,\"accountId\":8164518,\"accountName\":\"User_1604402150137\",\"createTime\":1604470004296,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2130800354,\"accountId\":8164509,\"accountName\":\"User_1604402150137\",\"createTime\":1604469959884,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1638871170,\"accountId\":8164502,\"accountName\":\"吃着包子看你浪の\",\"createTime\":1604469921432,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"悟空清理\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"上海极客公社企业发展有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2130800354,\"accountId\":8164499,\"accountName\":\"User_1604402150137\",\"createTime\":1604469903315,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2130800354,\"accountId\":8164482,\"accountName\":\"User_1604402150137\",\"createTime\":1604469798582,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2130800354,\"accountId\":8164466,\"accountName\":\"User_1604402150137\",\"createTime\":1604469730467,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2130800354,\"accountId\":8164448,\"accountName\":\"User_1604402150137\",\"createTime\":1604469659927,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2130800354,\"accountId\":8164430,\"accountName\":\"User_1604402150137\",\"createTime\":1604469597582,\"balance\":0,\"creditBalance\":30000000,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":30000000,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2130800354,\"accountId\":8164416,\"accountName\":\"User_1604402150137\",\"createTime\":1604469544241,\"balance\":0,\"creditBalance\":29062555,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":29062555,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2130800354,\"accountId\":8164402,\"accountName\":\"User_1604402150137\",\"createTime\":1604469449021,\"balance\":0,\"creditBalance\":27070426,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":27070426,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163799,\"accountName\":\"User_1604369195777\",\"createTime\":1604462940737,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163717,\"accountName\":\"User_1604369195777\",\"createTime\":1604462305459,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163692,\"accountName\":\"User_1604369195777\",\"createTime\":1604462147460,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163657,\"accountName\":\"User_1604369195777\",\"createTime\":1604461992416,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163639,\"accountName\":\"User_1604369195777\",\"createTime\":1604461873974,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163617,\"accountName\":\"User_1604369195777\",\"createTime\":1604461737411,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163609,\"accountName\":\"User_1604369195777\",\"createTime\":1604461695326,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163591,\"accountName\":\"User_1604369195777\",\"createTime\":1604461592502,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163574,\"accountName\":\"User_1604369195777\",\"createTime\":1604461488453,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163558,\"accountName\":\"User_1604369195777\",\"createTime\":1604461393283,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163551,\"accountName\":\"User_1604369195777\",\"createTime\":1604461346467,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163535,\"accountName\":\"User_1604369195777\",\"createTime\":1604461197577,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163525,\"accountName\":\"User_1604369195777\",\"createTime\":1604461140986,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163504,\"accountName\":\"User_1604369195777\",\"createTime\":1604461042813,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163499,\"accountName\":\"User_1604369195777\",\"createTime\":1604460995822,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163479,\"accountName\":\"User_1604369195777\",\"createTime\":1604460911364,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8163463,\"accountName\":\"User_1604369195777\",\"createTime\":1604460840930,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2130732745,\"accountId\":8159827,\"accountName\":\"User_1604396549121\",\"createTime\":1604400481716,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱聊\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"深圳市金运网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2130732745,\"accountId\":8159820,\"accountName\":\"User_1604396549121\",\"createTime\":1604400416838,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱聊\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"深圳市金运网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2128767698,\"accountId\":8159532,\"accountName\":\"王者风范＠\",\"createTime\":1604397580986,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"捕鱼大作战\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"棋牌捕鱼\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"在线途游（北京）科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129490843,\"accountId\":8158956,\"accountName\":\"User_1604372835909\",\"createTime\":1604393785966,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱奇艺随刻\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"影音娱乐\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京爱奇艺科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129490843,\"accountId\":8158929,\"accountName\":\"User_1604372835909\",\"createTime\":1604393622425,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱奇艺随刻\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"影音娱乐\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京爱奇艺科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129490843,\"accountId\":8158919,\"accountName\":\"User_1604372835909\",\"createTime\":1604393583879,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱奇艺随刻\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"影音娱乐\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京爱奇艺科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129490843,\"accountId\":8158908,\"accountName\":\"User_1604372835909\",\"createTime\":1604393484408,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱奇艺随刻\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"影音娱乐\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京爱奇艺科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129490843,\"accountId\":8158895,\"accountName\":\"User_1604372835909\",\"createTime\":1604393395225,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱奇艺随刻\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"影音娱乐\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京爱奇艺科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129625900,\"accountId\":8158214,\"accountName\":\"User_1604385980168\",\"createTime\":1604389630359,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129625900,\"accountId\":8158198,\"accountName\":\"User_1604385980168\",\"createTime\":1604389558683,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129625900,\"accountId\":8158175,\"accountName\":\"User_1604385980168\",\"createTime\":1604389480680,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129625900,\"accountId\":8158160,\"accountName\":\"User_1604385980168\",\"createTime\":1604389415393,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129625900,\"accountId\":8158143,\"accountName\":\"User_1604385980168\",\"createTime\":1604389345810,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129625900,\"accountId\":8158137,\"accountName\":\"User_1604385980168\",\"createTime\":1604389294694,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"淘宝特价版\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"淘宝(中国)软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129502027,\"accountId\":8158097,\"accountName\":\"User_1604374129772\",\"createTime\":1604389117797,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"飞鱼清理\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"上海极客公社企业发展有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1224385677,\"accountId\":8157345,\"accountName\":\"Hann\uD83D\uDCA6391\",\"createTime\":1604385348057,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"易车\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京易车信息科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1224385677,\"accountId\":8157310,\"accountName\":\"Hann\uD83D\uDCA6391\",\"createTime\":1604385189658,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"易车\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京易车信息科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8157160,\"accountName\":\"User_1604369195777\",\"createTime\":1604384423609,\"balance\":19999045,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":926,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":19999971,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8157146,\"accountName\":\"User_1604369195777\",\"createTime\":1604384341149,\"balance\":19999074,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":926,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":20000000,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129461653,\"accountId\":8157125,\"accountName\":\"User_1604369195777\",\"createTime\":1604384200568,\"balance\":19997508,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":926,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":19998434,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129459012,\"accountId\":8157102,\"accountName\":\"MIYA\",\"createTime\":1604384098298,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129459012,\"accountId\":8157083,\"accountName\":\"MIYA\",\"createTime\":1604384030060,\"balance\":18823825,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":791,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":18824616,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"2020-11-03\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129459012,\"accountId\":8157068,\"accountName\":\"MIYA\",\"createTime\":1604383974290,\"balance\":19806448,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":791,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":19807239,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"2020-11-03\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129459012,\"accountId\":8157054,\"accountName\":\"MIYA\",\"createTime\":1604383910070,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129459012,\"accountId\":8157046,\"accountName\":\"MIYA\",\"createTime\":1604383854338,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129459012,\"accountId\":8157038,\"accountName\":\"MIYA\",\"createTime\":1604383809082,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129459012,\"accountId\":8157023,\"accountName\":\"MIYA\",\"createTime\":1604383747260,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2129459012,\"accountId\":8157011,\"accountName\":\"MIYA\",\"createTime\":1604383674716,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2128756995,\"accountId\":8155863,\"accountName\":\"黄大琪\",\"createTime\":1604373950266,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"欢乐盖大楼\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"上海桥瀚科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2122908638,\"accountId\":8152495,\"accountName\":\"作息\",\"createTime\":1604315172078,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"刀锋电竞\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"安徽省刀锋网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123159506,\"accountId\":8152124,\"accountName\":\"User_1603789506888\",\"createTime\":1604312439415,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"ffit8旗舰店\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"电商商家\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京幸福能量健康科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123159506,\"accountId\":8151987,\"accountName\":\"User_1603789506888\",\"createTime\":1604311492089,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"ffit8旗舰店\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"电商商家\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京幸福能量健康科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123159506,\"accountId\":8151925,\"accountName\":\"User_1603789506888\",\"createTime\":1604310990661,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"ffit8旗舰店\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"电商商家\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京幸福能量健康科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123159506,\"accountId\":8151901,\"accountName\":\"User_1603789506888\",\"createTime\":1604310799391,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"ffit8旗舰店\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"电商商家\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京幸福能量健康科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2128828507,\"accountId\":8151367,\"accountName\":\"User_1604304058197\",\"createTime\":1604307524501,\"balance\":19999584,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":416,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":20000000,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2128828507,\"accountId\":8151319,\"accountName\":\"User_1604304058197\",\"createTime\":1604307244336,\"balance\":19999584,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":416,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":20000000,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2128828507,\"accountId\":8151264,\"accountName\":\"User_1604304058197\",\"createTime\":1604306862429,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2128653208,\"accountId\":8150392,\"accountName\":\"User_1604288174614\",\"createTime\":1604301883680,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"开车去浪\",\"firstCostDay\":\"-\",\"industry\":\"旅游类\",\"secondIndustry\":\"其他旅游类\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"太原可观嘉联网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2128653208,\"accountId\":8150319,\"accountName\":\"User_1604288174614\",\"createTime\":1604301411449,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"开车去浪\",\"firstCostDay\":\"-\",\"industry\":\"旅游类\",\"secondIndustry\":\"其他旅游类\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"太原可观嘉联网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8150271,\"accountName\":\"User_1603956272981\",\"createTime\":1604301151327,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8150256,\"accountName\":\"User_1603956272981\",\"createTime\":1604301062495,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8150233,\"accountName\":\"User_1603956272981\",\"createTime\":1604300968340,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8150217,\"accountName\":\"User_1603956272981\",\"createTime\":1604300870833,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8150203,\"accountName\":\"User_1603956272981\",\"createTime\":1604300794979,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8150185,\"accountName\":\"User_1603956272981\",\"createTime\":1604300680245,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8150168,\"accountName\":\"User_1603956272981\",\"createTime\":1604300587018,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8150156,\"accountName\":\"User_1603956272981\",\"createTime\":1604300501854,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8150136,\"accountName\":\"User_1603956272981\",\"createTime\":1604300388269,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8150124,\"accountName\":\"User_1603956272981\",\"createTime\":1604300325841,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8150107,\"accountName\":\"User_1603956272981\",\"createTime\":1604300202657,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8149993,\"accountName\":\"User_1603956272981\",\"createTime\":1604299604231,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8149972,\"accountName\":\"User_1603956272981\",\"createTime\":1604299483766,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8149945,\"accountName\":\"User_1603956272981\",\"createTime\":1604299313107,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8149931,\"accountName\":\"User_1603956272981\",\"createTime\":1604299227439,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8149897,\"accountName\":\"User_1603956272981\",\"createTime\":1604299100781,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8149862,\"accountName\":\"User_1603956272981\",\"createTime\":1604298897483,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8149843,\"accountName\":\"User_1603956272981\",\"createTime\":1604298792982,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1912290458,\"accountId\":8149800,\"accountName\":\"焦糖\",\"createTime\":1604298548434,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"焦糖\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州随手玩网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]}],\"host-name\":\"ad-rs1832.idczw.hb1.kwaidc.com\"}";
        ObjectMapper mapper = new ObjectMapper();
        mapper.disable(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES);
        JsonNode resultNode = mapper.readTree(result);
        Integer code = resultNode.get("result").intValue();
        if (code == 1) {
            Iterator<JsonNode> iterator1 = resultNode.get("adDspAccountList").elements();
            int i = 0;
            List<KuaishouAgentAccount> accountList = new ArrayList<>();
            while (iterator1.hasNext()) {
                JsonNode dataNode = iterator1.next();
                KuaishouAgentAccount agentAccount = mapper.readValue(dataNode.toString(), KuaishouAgentAccount.class);
                agentAccount.setBalance(agentAccount.getBalance().divide(new BigDecimal(1000)));
                agentAccount.setContractRebate(agentAccount.getContractRebate().divide(new BigDecimal(1000)));
                agentAccount.setCreditBalance(agentAccount.getCreditBalance().divide(new BigDecimal(1000)));
                agentAccount.setDirectRebate(agentAccount.getDirectRebate().divide(new BigDecimal(1000)));
                agentAccount.setExtendedBalance(agentAccount.getExtendedBalance().divide(new BigDecimal(1000)));
                agentAccount.setKuaibiBalance(agentAccount.getKuaibiBalance().divide(new BigDecimal(1000)));
                agentAccount.setPreRebate(agentAccount.getPreRebate().divide(new BigDecimal(1000)));
                agentAccount.setPushBalance(agentAccount.getPushBalance().divide(new BigDecimal(1000)));
                agentAccount.setRebate(agentAccount.getRebate().divide(new BigDecimal(1000)));
                agentAccount.setTotalBalance(agentAccount.getTotalBalance().divide(new BigDecimal(1000)));
                accountList.add(agentAccount);
            }
            if (!accountList.isEmpty()) {
                kuaishouAgentAccountMapper.replaceBatch(accountList);
            }
        }
    }
    @Autowired
    private IKuaishouInterfaceService kuaishouInterfaceService;

    @Test
    public void loadKuaishouGroupData() throws ParseException {
        Date endDate = new Date();
        String anotherDay = DateUtils.getAnotherDay("yyyy-MM-dd", DateUtils.formatDate(endDate), -1);
        SimpleDateFormat sim = new SimpleDateFormat("yyyy-MM-dd");
        Date startDate = sim.parse(anotherDay);
        CtopOauthToken token = tokenService.getTokenByAccountId(7087890L);
        kuaishouInterfaceService.getGroupList(token, startDate, endDate);
    }



    @Test
    public void loadAccountData() {
//        List<UserAllocation> allocations = allocationService.getByParams(776L,null,0);
//        for (UserAllocation allocation:allocations) {
            CtopOauthToken token = tokenService.getTokenByAccountId(93238965516L);
            for(int i=92;i<100;i++){
                Date getDate = DateUtils.addDay(new Date(),-i);
                reportService.getAdvertiserReport(token, getDate, getDate, CtopAdConstant.BYTEDANCE_REPORT_TYPE_DAILY);
            }
//        }
    }

    @Autowired
    IUReportExportService uReportExportService;
    @Autowired
    EmailSendMsgHandle emailSendMsgHandle;
    @Autowired
    IUReportService uReportService;

    @Test
    public void loadBytedanceData(){
        List<CtopOauthToken> tokens = tokenService.selectToutiaoToken();
        for (int i=0;i<tokens.size();i++) {
            for(int j=0;j<4;j++){
                String getDate = DateUtils.formatDate(DateUtils.addDay(new Date(), -j));
                bytedanceReportService.bytedanceVideoMaterialReport(tokens.get(i), getDate, getDate);
            }
        }
    }

    @Autowired
    private IBytedanceReportService bytedanceReportService;
    @Test
    public void loadMatData(){
        List<UserAllocation> allocations = allocationService.getByParams(289L,null,0);
        countDownLatch = new CountDownLatch(allocations.size());
        executorService = Executors.newFixedThreadPool(2);
        allocations.forEach(allocation -> {
            executorService.submit(new Runnable() {
                @Override
                public void run() {
                    try {
                        CtopOauthToken token = tokenService.getTokenByAccountId(allocation.getAccountId());
                        //获取全量视频素材数据
                        advertiserDataService.getMaterialList(token);
                    } catch (Exception e) {
                        e.printStackTrace();
                    } finally {
                        countDownLatch.countDown();
                    }
                }
            });
        });
        try {
            countDownLatch.await();
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        XxlJobLogger.log("物料数据同步完成");
    }
}
